@@ -616,11 +616,15 @@ class SagemakerFeatureStore:
         None
         """
 
+        feature_group_names = []
         print("LIST OF FEATURE GROUPS:")
         for group in self.sagemaker_client.list_feature_groups(MaxResults=100)[
             "FeatureGroupSummaries"
         ]:
             print(group["FeatureGroupName"])
+            feature_group_names.append(group["FeatureGroupName"])
+
+        return feature_group_names
 
     def _reformat_to_dict(self, record: dict):
         """
@@ -750,7 +754,7 @@ if __name__ == "__main__":
     # )
 
     # # Get Online Features by Single ID
-    # features_list = ["streamer_id", "cover_photo_embedding"]
+    # features_list = ["customer_id", "state_code"]
 
     # t0 = time.time()
     # raw_data = feature_store.get_online_features(
@@ -787,7 +791,7 @@ if __name__ == "__main__":
     # might need to wait a few minutes..
     # time.sleep(5)
 
-    # Offline Store Query Example
+    # # Offline Store Query Example
     # feature_group = feature_store.get_feature_group(feature_group_name)
     # fg_query_instance = feature_group.athena_query()
     # fg_table = fg_query_instance.table_name
@@ -804,7 +808,7 @@ if __name__ == "__main__":
     # print(training_df.iloc[0])
 
     # List Feature Groups
-    # feature_store.get_feature_groups_list()
+    print(feature_store.get_feature_groups_list())
 
     # Describe feature group
     # feature_store.describe_feature_group("v3-cross-test")
